git

package
v1.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 18, 2020 License: MIT Imports: 1 Imported by: 0

Documentation

Overview

Package git is a facade for git methods used by mirror

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Clone

func Clone(dir string, opts CloneOptions) error

Clone clones a git repository with the given options

Types

type CloneOptions

type CloneOptions git.CloneOptions

CloneOptions are used when cloning a git repository

type Foo

type Foo struct{}

Foo ...

Jump to